// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', [
    'ionic',
    'controllers.main',
    'controllers.app.welcome',
    'controllers.auth',

    'controllers.item',
    'controllers.item.list',
    'controllers.item.detail',
    'controllers.item.sellerHome',
    'controllers.item.reviews',
    'controllers.item.choose',
    'controllers.item.calendar',
    'controllers.item.pay',
    'controllers.item.couponUse',

    'controllers.seller',
    'controllers.seller.apply',
    'controllers.seller.goodsList',
    'controllers.seller.goodsEdit',
    'controllers.seller.goodsPreview',
    'controllers.seller.shopEdit',
    'controllers.seller.orderList',
    'controllers.seller.orderDetail',

    'controllers.user',
    'controllers.user.tradeList',
    'controllers.user.tradeEditInfo',
    'controllers.user.cms',

    'services.common.auth',
    'services.common.constants',
    'services.common.device',
    'services.models.calendar',
    'ngCordova',
    'ionicLazyLoad',
    'swipeSlider'

])

.run(function($ionicPlatform, AuthService, Constants, $state, $rootScope,$http, $cordovaDialogs, $location,
              $cordovaNetwork,$ionicLoading,$cordovaInAppBrowser, DeviceService) {

    $ionicPlatform.ready(function() {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
			cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
		  //cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
			window.cordova.plugins.Keyboard.disableScroll(true)
        }
        if (window.StatusBar) {
          // org.apache.cordova.statusbar required
          StatusBar.styleLightContent();
        }


    });

    DeviceService.init();
    //AuthService.init();

    //打开webview
    $rootScope.openWebURL =  function(url) {
        var options = {location: 'no', closebuttoncaption: '关闭', clearcache: 'yes', toobarBar:'yes'};
        $cordovaInAppBrowser.open(url, '_blank', options);
    }

    document.addEventListener("deviceready", function () {
        $rootScope.shareToWeixin = function(shareInfo){
            var shareType =  WeChat.Scene.session;
            if(shareInfo.type == 'timeline') {
                shareType = WeChat.Scene.timeline;
            }
            WeChat.share(
                {
                    title: shareInfo.title,
                    description: shareInfo.desc,
                    url: shareInfo.url,
                    thumbURL:shareInfo.thumbURL
                },
                shareType, function () {
                    console.log('分享成功~');
                }, function (reason) {
                    // 分享失败
                    console.log(reason);
                });
        };

        cordova.getAppVersion.getVersionCode(function (code) {
                console.log(code);
            })
    });


    window.addEventListener("Gexin.receiveNotification", function (a) {
        $cordovaDialogs.confirm(a.message, a.title, ['确定', '取消'])
        .then(function() {

        });
    });

    var localSellerId = window.localStorage.getItem('localSellerId');
    $rootScope.showDash = true;

    if(!localSellerId || localSellerId == 'undefined' || localSellerId <= 0) {
        $rootScope.showDash = false;
    }

    $rootScope.isLogin = window.localStorage.getItem('isLogin');
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider, $httpProvider){

    $ionicConfigProvider.backButton.previousTitleText(false).text('');

    //android和ios一样的style
    $ionicConfigProvider.tabs.position('bottom');
    $ionicConfigProvider.tabs.style('standard');
    $ionicConfigProvider.navBar.alignTitle('center');
    $ionicConfigProvider.views.swipeBackEnabled(false);


    $httpProvider.defaults.transformRequest = function(obj){
      var str = [];
      for(var p in obj){
        str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
      }
      return str.join("&");
    }

    $httpProvider.defaults.headers.post = {
      'Content-Type': 'application/x-www-form-urlencoded'
    }

    // Ionic uses AngularUI Router which uses the concept of states
    // Learn more here: https://github.com/angular-ui/ui-router
    // Set up the various states which the app can be in.
    // Each state's controller can be found in controllers.js

    $stateProvider
    .state('app', {
        url: "/app",
        abstract: true,
        templateUrl: "templates/tabs.html",
        controller:'AppCtrl'
    })

    //引导页面
    .state('welcome', {
        url: '/',
        templateUrl: 'templates/welcome.html',
            controller:'WelcomeCtrl'
    })

    //登录页面
    .state('login', {
        url: '/login',
        templateUrl: 'templates/auth/login.html',
        controller: 'AuthCtrl'
    })
    //注册页面，第一步
    .state('register/step1', {
        url: '/register',
        templateUrl: 'templates/auth/register-step1.html',
        controller: 'AuthCtrl'
    })
    //注册页面，第二步
    .state('register/step2', {
        url: '/register/step2',
        templateUrl: 'templates/auth/register-step2.html',
        controller: 'AuthCtrlStep2'
    })
    //注册页面，第三步
    .state('register/step3', {
        url: '/register/step3',
        templateUrl: 'templates/auth/register-step3.html',
        controller: 'AuthCtrl'
    })

    .state('app.dash', {
        url: '/dash',
        views: {
            'tab-dash': {
                templateUrl: 'templates/seller/dash.html',
                controller: 'DashCtrl'
            }
        }
    })
    .state('app.apply', {
        url: '/dash/apply',
        views: {
            'tab-dash': {
                templateUrl: 'templates/seller/apply2.html',
                controller: 'ApplyCtrl'
            }
        }
    })
    .state('app.sellerEdit', {
        url: '/seller/sellerEdit',
        views: {
            'tab-dash': {
                templateUrl: 'templates/seller/shopEdit.html',
                controller: 'SellerEditCtrl'
            }
        }
    })
    //商家服务列表页面
    .state('app.goodsList', {
        url: '/seller/goods',
        views: {
            'tab-dash' : {
                templateUrl: 'templates/seller/goods.html',
                controller: 'GoodsListCtrl'
            }
        }
    })
    //商家商品编辑页面
    .state('app.goodsEdit', {
        url: '/seller/goods/edit/:goodsId',
        views: {
            'tab-dash' : {
                templateUrl: 'templates/seller/goods-edit.html',
                controller: 'GoodsEditCtrl'
            }
        }
    })
    .state('app.goodsImageEdit', {
        url: '/seller/goods/imageEdit',
        views: {
            'tab-dash' : {
                templateUrl: 'templates/seller/goods-image-edit.html',
                controller: 'GoodsImageEditCtrl'
            }
        },
        params: {
            obj:null
        }
    })
    .state('app.goodsPreview', {
        url: '/seller/goods/preview/:itemId',
        views: {
            'tab-dash' : {
                templateUrl: 'templates/seller/goods-preview.html',
                controller: 'GoodsPreviewCtrl'
            }
        }
    })
    .state('app.orderList', {
        url: '/seller/orders',
        views: {
            'tab-dash' : {
                templateUrl : 'templates/seller/orders.html',
                controller: 'OrderListCtrl'
            }
        }
    })
    .state('app.orderDetail', {
        url: '/seller/order/:orderId',
        views: {
            'tab-dash' : {
                templateUrl : 'templates/seller/order-detail.html',
                controller: 'OrderDetailCtrl'
            }
        }
    })
    .state('app.home', {
        url: '/home',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/home.html',
                controller: 'ItemCtrl'
            }
        }
    })
    .state('app.itemList', {
        url: '/itemList/:areaId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/list.html',
                controller: 'ItemListCtrl'
            }
        },
        params: {
            areaName:null
        }
    })
    .state('app.itemDetail', {
        url: '/item/:itemId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/detail.html',
                controller: 'ItemDetailCtrl'
            }
        }
    })
    .state('app.itemSellerHome', {
        url: '/item/sellerHome/:localSellerId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/seller-home.html',
                controller: 'SellerHomeCtrl'
            }
        }
    })
    .state('app.itemSellerIntroduce', {
        url: '/item/sellerIntroduce/:localSellerId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/seller-intro.html',
                controller: 'SellerIntroduceCtrl'
            }
        }
    })
    .state('app.itemReviews', {
        url: '/item/reviews/:itemId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/reviews.html',
                controller: 'ItemReviewsCtrl'
            }
        }
    })
    .state('app.itemChoose', {
        url: '/choose/:itemId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/choose.html',
                controller: 'ItemChooseCtrl'
            }
        }
    })
    .state('app.itemCalendar', {
        url: '/calendar/:itemId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/calendar.html',
                controller: 'ItemCalendarCtrl'
            }
        }
    })
    .state('app.itemPay', {
        url: '/pay/:tradeId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/pay.html',
                controller: 'ItemPayCtrl'
            }
        }
    })
    .state('app.couponUse', {
        url: '/coupon/use/:tradeId',
        views: {
            'tab-item': {
                templateUrl: 'templates/item/coupon-use.html',
                controller: 'CouponUseCtrl'
            }
        }
    })
    .state('app.itemTradeList', {
            url: '/item/tradeList',
            views: {
                'tab-item': {
                    controller: 'TradeListCtrl',
                    templateUrl: 'templates/user/tradeList.html'
                }
            }
        })
    .state('app.mine', {
        url:'/mine',
        views: {
            'tab-mine' : {
                controller: 'UserCtrl',
                templateUrl: 'templates/user/mine.html'
            }
        }
    })
    .state('app.userEditInfo', {
        url:'/mine/editInfo',
        views: {
            'tab-mine' : {
                controller: 'UserCtrl',
                templateUrl: 'templates/user/edit-info.html'
            }
        }
    })
    .state('app.aboutApp', {
        url:'/mine/cms/:cmsId',
        views: {
            'tab-mine' : {
                controller: 'UserCmsCtrl',
                templateUrl: 'templates/user/about-app.html'
            }
        }
    })
    .state('app.mineTradeList', {
        url:'/mine/tradeList',
        views: {
            'tab-mine' : {
                controller: 'TradeListCtrl',
                templateUrl: 'templates/user/tradeList.html'
            }
        }
    })
    .state('app.trade-editInfo', {
            url: '/mine/editTradeInfo/:tradeId',
            views: {
                'tab-mine' :{
                    templateUrl: 'templates/user/tradeEditInfo.html',
                    controller: 'TradeEditInfoCtrl'
                }
            }
    });

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/');

}).filter('to_trusted', ['$sce', function($sce){
        return function(text) {
            return $sce.trustAsHtml(text);
        };
    }])
    .directive('showContent', ['$compile', function ($compile) {
        return {
            scope: true,
            link: function($scope, $element, $attrs) {
                var el;
                $attrs.$observe('template', function (tpl) {
                    var reg = /<a [^>]*href=['"]([^'"]+)[^>]*>/gi;
                    if(tpl) {
                        tpl  = tpl.replace(reg, function(match, capture){
                            return '<a ng-click=openWebURL("' + capture + '") >';
                        });
                    }
                    el = $compile('<div>'+tpl+'</div>')($scope);
                    $element.html("");
                    $element.append(el);
                });
            }
        };
    }])
    .directive('autoFocusWhen', ['$log','$timeout', function($log, $timeout) {
        return {
            restrict: 'A',
            scope: {
                autoFocusWhen: '='
            },
            link: function(scope, element) {
                scope.$watch('autoFocusWhen', function(newValue) {
                    if (newValue) {
                        $timeout(function(){
                            element[0].focus();
                        })
                    }
                });
                element.on('blur', function() {
                    scope.$apply(function() {
                        scope.autoFocusWhen = false;
                    })
                })
            }
        }
    }]);;
