/**
 * Created by cgeek on 5/20/15.
 */

angular.module('services.models.goods',[])
.factory('GoodsModel',function($http, $q, Constants) {

    var service = {};

    service.getAll = function(params){
        var deferred = $q.defer();

        var data = {'qglUserId':window.localStorage.getItem('userId')};
        if(params) {
            var data = angular.extend(data, params)
        }

        $http({
            method:'POST',
            url: Constants.API.baseURL + '/localSellerItemList',
            data: data,
            'Content-Type': 'application/x-www-form-urlencoded'
        }).success(function(data){
            deferred.resolve(data);
        }).error(function(){
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.getOne = function(goodsId) {
        var deferred = $q.defer();

        var data = {'goodsId': goodsId};
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/localSellerItemDetail',
            data: data
        }).success(function(data){
            deferred.resolve(data);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.getEditDetail = function (goodsId) {
        var deferred = $q.defer();

        var data = {'itemId': goodsId};
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/itemEditInfo',
            data: data
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.updateItemInfo = function(good) {
        var deferred = $q.defer();

        var data = {'qglUserId':window.localStorage.getItem('userId')};
        data = angular.extend(data, good)

        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/saveItem',
            data: data
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.create = function() {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }

        //判断是否已经有临时ITEM
        var tempItemId = window.localStorage.getItem('tempItemId');
        if(tempItemId && tempItemId > 0) {
            deferred.resolve(tempItemId);
        } else {
            $http({
                method: 'POST',
                url: Constants.API.baseURL + '/createItem',
                data: {qglUserId: userId}
            }).success(function(result){
                if(result.success) {
                    deferred.resolve(result.data);
                    var tempItemId = window.localStorage.setItem('tempItemId', result.data);
                } else {
                    deferred.reject('服务器正忙...');
                }
            }).error(function() {
                deferred.reject('服务器正忙...');
            });
        }

        return deferred.promise;
    }

    service.delete = function(goodsId) {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/deleteItem',
            data: {itemId:goodsId, qglUserId: userId}
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.deleteSku = function(id) {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/deleteSku',
            data: {id:id}
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }
    service.createSku = function(goodsId, sku) {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/createSku',
            data: {'item.id':goodsId, name:sku.name, price:sku.price, unit:sku.unit}
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }
    service.updateSku = function(skuId, sku) {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/updateSku',
            data: {'id':skuId, name:sku.name, price:sku.price, unit:sku.unit}
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }

    service.deleteImage = function(imageId) {
        var deferred = $q.defer();

        var userId = window.localStorage.getItem('userId');
        if(!userId || userId < 0) {
            deferred.reject('还没有登录');
            return deferred.promise;
        }
        $http({
            method: 'POST',
            url: Constants.API.baseURL + '/deleteItemImage',
            data: {'imageId':imageId, 'userId':userId}
        }).success(function(result){
            deferred.resolve(result);
        }).error(function() {
            deferred.reject('服务器正忙...');
        });

        return deferred.promise;
    }
    return service;


});
